==> BetterString-2.10.1.tar.gz: BetterString-2.10.1/README.md <==
<!--
This Readme is from: https://github.com/othneildrew/Best-README-Template
*** Thanks for checking out the Best-README-Template. If you have a suggestion
*** that would make this better, please fork the repo and create a pull request
*** or simply open an issue with the tag "enhancement".
*** Thanks again! Now go create something AMAZING! :D
-->

<!--
<p align="center">

[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![Python][Python-shield]][Python-url]
</p>
-->
<div class="grid-container">
<div class="Header">
<p align="center">

<a href="https://github.com/DrBumm/BetterString/network/members"><img src="https://img.shields.io/github/forks/DrBumm/BetterString?style=for-the-badge" alt="Forks"></a>
<a href="https://github.com/DrBumm/BetterString/stargazers"><img src="https://img.shields.io/github/stars/DrBumm/BetterString?style=for-the-badge" alt="Stargazers"></a>
<a href="https://github.com/DrBumm/BetterString/issues"><img src="https://img.shields.io/github/issues/DrBumm/BetterString?style=for-the-badge" alt="Issues"></a>
<a href="https://python.org/"><img src="https://img.shields.io/badge/Python-%3E%3D3.8-informational?style=for-the-badge&amp;logo=appveyor" alt="Python"></a>
</p>

<!-- PROJECT SHIELDS -->
<!--
*** I'm using markdown "reference style" links for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->

<!-- PROJECT LOGO -->

<p align="center">
  <h3 align="center">BetterString</h3>

  <p align="center">
    Like a normal string but with more functionality
    <br />
    <a href="https://github.com/DrBumm/BetterString/blob/main/docs/README.md"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/DrBumm/BetterString/issues">Report Bug</a>
    ·
    <a href="https://github.com/DrBumm/BetterString/issues">Request Feature</a>
    <br />
    <a href="https://github.com/DrBumm/BetterString/">View source code</a>
  </p>
</p>



<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#contributing">Contributing</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project


### Built With

* [Python](https://python.org/)



<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple example steps.

### Prerequisites
Python >= 3.6

### Installation
1. Open a terminal
2. `pip install BetterString`   
If it doesn't work, try:  
   `pip3 install BetterString`
   
If it still doesn't work install pip or install a supported python version

<!-- USAGE EXAMPLES -->
## Usage
After Installing import BetterStrings and you can use it! For more information:    
Go to the [Documentation](https://github.com/DrBumm/BetterString/blob/main/docs/README.md)

<!-- CONTRIBUTING -->
## Contributing

Contributions are what makes the open source community such an amazing place to learn, inspire and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[forks-shield]: https://img.shields.io/github/forks/DrBumm/BetterString?style=for-the-badge
[forks-url]: https://github.com/DrBumm/BetterString/network/members
[stars-shield]: https://img.shields.io/github/stars/DrBumm/BetterString?style=for-the-badge
[stars-url]: https://github.com/DrBumm/BetterString/stargazers
[issues-shield]: https://img.shields.io/github/issues/DrBumm/BetterString?style=for-the-badge
[issues-url]: https://github.com/DrBumm/BetterString/issues
[python-shield]: https://img.shields.io/badge/Python-%3E%3D3.6-informational?style=for-the-badge&logo=appveyor
[python-url]: https://python.org/

==> BetterString-2.16.7.tar.gz: BetterString-2.16.7/README.md <==
<!--
This Readme is from: https://github.com/othneildrew/Best-README-Template
*** Thanks for checking out the Best-README-Template. If you have a suggestion
*** that would make this better, please fork the repo and create a pull request
*** or simply open an issue with the tag "enhancement".
*** Thanks again! Now go create something AMAZING! :D
-->

<!--
<p align="center">

[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![Python][Python-shield]][Python-url]
</p>
-->
<div class="grid-container">
<div class="Header">
<p align="center">

<a href="https://github.com/DerSchinken/BetterString/network/members"><img src="https://img.shields.io/github/forks/DerSchinken/BetterString?style=for-the-badge" alt="Forks"></a>
<a href="https://github.com/DerSchinken/BetterString/stargazers"><img src="https://img.shields.io/github/stars/DerSchinken/BetterString?style=for-the-badge" alt="Stargazers"></a>
<a href="https://github.com/DerSchinken/BetterString/issues"><img src="https://img.shields.io/github/issues/DerSchinken/BetterString?style=for-the-badge" alt="Issues"></a>
<a href="https://python.org/"><img src="https://img.shields.io/badge/Python-%3E%3D3.8-informational?style=for-the-badge&amp;logo=appveyor" alt="Python"></a>
</p>

<!-- PROJECT SHIELDS -->
<!--
*** I'm using markdown "reference style" links for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->

<!-- PROJECT LOGO -->

<p align="center">
  <h3 align="center">BetterString</h3>

  <p align="center">
    Like a normal string but with more functionality
    <br />
    <a href="https://github.com/DerSchinken/BetterString/blob/main/docs/README.md"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/DerSchinken/BetterString/issues">Report Bug</a>
    ·
    <a href="https://github.com/DerSchinken/BetterString/issues">Request Feature</a>
    <br />
    <a href="https://github.com/DerSchinken/BetterString/">View source code</a>
  </p>
</p>



<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#contributing">Contributing</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project


### Built With

* [Python](https://python.org/)      


<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple example steps.

### Prerequisites
Python >= 3.7

### Installation
1. Open a terminal
2. `pip install BetterString`   
If it doesn't work, try:  
   `pip3 install BetterString`
   
If it still doesn't work install pip or install a supported python version

<!-- USAGE EXAMPLES -->
## Usage
After Installing import BetterStrings and you can use it! For more information:    
Go to the [Documentation](https://github.com/DerSchinken/BetterString/blob/main/docs/README.md)

<!-- CONTRIBUTING -->
## Contributing

Contributions are what makes the open source community such an amazing place to learn, inspire and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request


<!-- Misc -->
## Misc   
The GitHub Pages Page is not quite finished


<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[forks-shield]: https://img.shields.io/github/forks/DerSchinken/BetterString?style=for-the-badge
[forks-url]: https://github.com/DerSchinken/BetterString/network/members
[stars-shield]: https://img.shields.io/github/stars/DerSchinken/BetterString?style=for-the-badge
[stars-url]: https://github.com/DerSchinken/BetterString/stargazers
[issues-shield]: https://img.shields.io/github/issues/DerSchinken/BetterString?style=for-the-badge
[issues-url]: https://github.com/DerSchinken/BetterString/issues
[python-shield]: https://img.shields.io/badge/Python-%3E%3D%203.7-blue?style=for-the-badge&logo=appveyor
[python-url]: https://python.org/
